@@ -4,12 +4,36 @@ use strict;
 use warnings FATAL => 'all';
 
 eval "use Spreadsheet::Read";
-our $NOT_AVAILABLE = $@;
+our $NO_READER = $@;
+
+eval "use URI";
+our $NO_URI = $@;
+eval "use LWP::Simple";
+our $NO_LWP = $@;
+eval "use File::Temp";
+our $NO_TEMP = $@;
+eval "use File::Basename";
+our $NO_BASE = $@;
+
 
 sub _parse {
     my ($args,$data) = @_;
-    my $file = $args->{file};
 
+    if ($args->{file} =~ m{^https?://}) {
+        if ($NO_URI or $NO_LWP or $NO_TEMP or $NO_BASE) {
+            return [[ "cannot download $args->{file}" ],[ 'please install URI, LWP::Simple, File::Basename and/or File::Temp' ]];
+        } else {
+            my $uri = URI->new( $args->{file} );
+            my @ext = qw( .html .htm .json .jsn .yaml .yml .gif .png .jpg .jpeg .csv .xls .xlsx .sxc .ods );
+            my (undef,undef,$suffix) = File::Basename::fileparse( $uri->path, @ext );
+            my (undef,$newfile) = File::Temp::tmpnam();
+            $args->{file} = $newfile . $suffix;
+            my $error = LWP::Simple::getstore( $uri->as_string, $args->{file} );
+            return [[ "cannot download " . $uri->as_string ],[ "RC code $error" ]] if LWP::Simple::is_error( $error );
+        }
+    }
+
+    my $file = $args->{file};
     if ($file =~ /\.html?$/) {
         return Spreadsheet::HTML::File::HTML::_parse( $args );
     } elsif ($file =~ /\.jso?n$/) {
@@ -21,7 +45,7 @@ sub _parse {
     }
 
     return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file or $file eq '-';
-    return [[ "cannot load $file" ],[ 'please install Spreadsheet::Read' ]] if $NOT_AVAILABLE;
+    return [[ "cannot load $file" ],[ 'please install Spreadsheet::Read' ]] if $NO_READER;
 
     my $workbook = ReadData( $file,
         attr    => $args->{preserve},
@@ -135,7 +159,7 @@ Parses with (requires) L<Imager::File::JPEG>.
   generate( file => 'foo.jpeg' )
   generate( file => 'foo.jpeg', block => 2 )
   generate( file => 'foo.jpeg', block => 2, blend => 1 )
-  generate( file => 'foo.jpeg', off => 'FFFFFF' )
+  generate( file => 'foo.jpeg', alpha => '#ffffff' )
 
 =item * PNG
 
@@ -144,7 +168,7 @@ Parses with (requires) L<Imager::File::PNG>.
   generate( file => 'foo.png' )
   generate( file => 'foo.png', block => 2 )
   generate( file => 'foo.png', block => 2, blend => 1 )
-  generate( file => 'foo.png', off => 'FFFFFF' )
+  generate( file => 'foo.png', alpha => '#ffffff' )
 
 =item * GIF
 
@@ -153,7 +177,7 @@ Parses with (requires) L<Imager::File::GIF>.
   generate( file => 'foo.gif' )
   generate( file => 'foo.gif', block => 2 )
   generate( file => 'foo.gif', block => 2, blend => 1 )
-  generate( file => 'foo.gif', off => 'FFFFFF' )
+  generate( file => 'foo.gif', alpha => '#ffffff' )
 
 =back
 
@@ -304,11 +328,16 @@ sub _parse {
                 }
             }
 
+            if ($args->{alpha}) {
+                $args->{alpha} =~ s/^#//;
+                $args->{alpha} = uc( $args->{alpha} );
+            }
+
             $args->{"-r${c}c${r}"} = {
                 width  => $args->{block} * 2,
                 height => $args->{block},
                 style  => { 'background-color' => "#$primary" },
-            } unless $args->{off} and $args->{off} eq $primary;
+            } unless $args->{alpha} and $args->{alpha} eq $primary;
 
             $c++;
         }
